@@ -199,10 +199,10 @@ sub pre_commit {
 	    my $from = $conf->{from};
 	    for my $file ($svnlook->added(), $svnlook->updated()) {
 		if (! ref $from) {
-		    next if $from ne $file;
+		    next if $file ne $from;
 		}
 		else {
-		    next if $from !~ $file;
+		    next if $file !~ $from;
 		}
 
 		my $text = $svnlook->cat($file);
@@ -391,7 +391,7 @@ L<http://search.cpan.org/dist/SVN-Hooks>
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2008 CPqD, all rights reserved.
+Copyright 2008-2009 CPqD, all rights reserved.
 
 This program is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
